@@ -16,19 +16,19 @@ class Tester:
         record = {'phase': 'training'}
         historical_expecting = sequence[-1]["strings"][-1]  # Will use the last string object in the last event.
         record['historical_expecting'] = historical_expecting
-        self.bottle.observe(CLEAR_WM)
+        self.bottle.clear_wm()
         for data in sequence[:-1]:  # Hold back the last event since it should have the classification.
             if data["vectors"] or data["strings"] or data["emotives"]:
                 self.bottle.observe(data)
         self.bottle.observe_classification(sequence[-1])  # Now, we want all the query nodes to get the classification.
-        self.bottle.observe(LEARN)
+        self.bottle.learn()
         return record
 
     def test(self, sequence):
         record = {'phase': 'testing'}
         historical_expecting = sequence[-1]["strings"][-1]  # Will use the last string object in the last event.
         record['historical_expecting'] = historical_expecting
-        self.bottle.observe(CLEAR_WM)
+        self.bottle.clear_wm()
         for data in sequence[:-1]:  # hold back the last event in the sequence because it contains the answer! Give to all query nodes later.
             if data["vectors"] or data["strings"] or data["emotives"]:
                 self.bottle.observe(data)
@@ -55,5 +55,5 @@ class Tester:
             # Now use the last event.
             self.bottle.observe_classification(
                 sequence[-1])  # Now, we want all the query nodes to get the classification.
-            self.bottle.observe(LEARN)
+            self.bottle.learn()
         return record
